@@ -1,9 +1,12 @@
 import os
 import json
 import importlib
+import pkg_resources
 
 provider_module = 'mext.providers'
-provider_file_name = 'mext/all_providers.json'
+provider_file_name = pkg_resources.resource_filename(
+    'mext', os.path.join('data','all_providers.json')
+)
 provider_file_path = os.path.abspath(provider_file_name)
 providers_json = json.load(open(provider_file_path))
 
@@ -11,7 +14,7 @@ providers_json = json.load(open(provider_file_path))
 def get_provider_instance(name=None, netloc=None):
     for provider_info in providers_json:
         if (name and provider_info['name'] == name) or \
-            (netloc and provider_info['netloc'] == netloc):
+                (netloc and provider_info['netloc'] == netloc):
             ProviderClass = globals()[provider_info['class']]
             return ProviderClass(
                 name=provider_info['name'],
